import java.util.*;
//import org.apache.commons.math3.util.Combinations;

//import org.apache.commons.lang3.ArrayUtils;

/**
 * Item with weight and value.
 * Internal use only.
 */
class KnapsackItem implements Comparable<KnapsackItem> {
	private long weight;
	private long value;

	public KnapsackItem(long weight, long value) {
		this.weight = weight;
		this.value = value;
	}

	public long getWeight() {
		return weight;
	}

	public long getValue() {
		return value;
	}

	public int compareTo(KnapsackItem item) {
		final long score = item.getWeight() * getValue();
		final long itemScore = getWeight() * item.getValue();
		final long diff = score - itemScore;

		// prevent overflow
		if (diff < 0) {
			return -1;
		} else if (diff > 0) {
			return 1;
		} else {
			return 0;
		}
	}
}

/**
 * Instance of the Knapsack Problem.
 * Total weight to be packed: getCapacity()
 * #items: getNumItems()
 * weight/value of i-th item: getWeight(i) / getValue(i)
 * sort() sorts items by (value/weight), in descending order
 */
class KnapsackInstance {
	private long capacity;
	private ArrayList<KnapsackItem> items;

	public KnapsackInstance(int size) {
		capacity = 0;
		items = new ArrayList<KnapsackItem>(size);
	}

	public long getCapacity() {
		return capacity;
	}

	public void setCapacity(long capacity) {
		this.capacity = capacity;
	}

	public void append(long weight, long value) {
		items.add(new KnapsackItem(weight, value));
	}

	public long getWeight(int i) {
		return items.get(i).getWeight();
	}

	public long getValue(int i) {
		return items.get(i).getValue();
	}

	public int getNumItems() {
		return items.size();
	}

	public void sort() {
		Collections.sort(items);
		Collections.reverse(items); // descending order
	}

	public String toString() {
		String description = "capacity=" + getCapacity();

		for (int i = 0; i < getNumItems(); ++i) {
			description += " / (weight_" + i + ", value_" + i + ") = (";
			description += getWeight(i);
			description += ", " + getValue(i) + ")";
		}

		return description;
	}
}

/**
 * This class stores solutions of a Knapsack instance.
 * The i-th boolean indicates whether the i-th item has been chosen.
 * The resulting weight/value/feasibility of the current solution is tracked.
 * Copy instances with copyFrom(...).
 */
class KnapsackSolution {
	KnapsackInstance knapsack;
	double[] choices;
	long weight;
	long value;

	public KnapsackSolution(KnapsackInstance kp) {
		knapsack = kp;
		choices = new double[kp.getNumItems()];
		clear();
	}

	public double get(int i) {
		return choices[i];
	}

	public void set(int i, double b) {
		if (choices[i] != b) {
			weight -= choices[i]*knapsack.getWeight(i);
			value -= choices[i]*knapsack.getValue(i);
			choices[i] = b;
			weight += (long)(b*(double)knapsack.getWeight(i));
			value += (long)(b*(double)knapsack.getValue(i));
		}
	}

	public long getWeight() {
		return weight;
	}

	public long getValue() {
		return value;
	}

	public boolean isFeasible() {
		return getWeight() <= knapsack.getCapacity();
	}

	public void clear() {
		for (int i = 0; i < choices.length; ++i) {
			choices[i] = 0;
		}

		weight = 0;
		value = 0;
	}

	public void copyFrom(KnapsackSolution solution) {
		knapsack = solution.knapsack;
		choices = new double[solution.choices.length];
		for (int i = 0; i < solution.choices.length; ++i) {
			choices[i] = solution.choices[i];
		}
		weight = solution.weight;
		value = solution.value;
	}

	public String toString() {
		String description
				= (isFeasible() ? "" : "INFEASIBLE! ")
				+ "Total Weight: " + getWeight()
				+ " / total value: " + getValue() + " / items:";
		for (int i = 0; i < choices.length; ++i) {
			if (choices[i] == 1) {
				description += " " + i;
			}else if (choices[i] > 0){
				description += " (" + String.format("%.2f",choices[i]) + ")*" + i;
			}
		}

		return description;
	}
}

/**
 * Here are the actual algorithms!
 */
public class Knapsack1234567 {
	// Parses input. Do not edit.
	public static KnapsackInstance readInstance() {
		Scanner scanner = new Scanner(System.in);
		KnapsackInstance kp = new KnapsackInstance(scanner.nextInt());

		while (scanner.hasNextLong()) {
			long capacity = scanner.nextLong();

			if (scanner.hasNextLong()) {
				long weight = scanner.nextLong();
				long value = scanner.nextLong();
				kp.append(weight, value);
			} else {
				kp.setCapacity(capacity);
			}
		}

		kp.sort();
		return kp;
	}

	public static KnapsackSolution bruteForce(KnapsackInstance kp) {
		return null; //TODO
	}
	
	public static KnapsackSolution fractional(KnapsackInstance kp) {
		return null; //TODO
	}
	
	public static KnapsackSolution greedy(KnapsackInstance kp) {
		return null; //TODO
	}

	public static KnapsackSolution dynamicProgramming(KnapsackInstance kp) {
		return null; //TODO
	}
	
public static KnapsackSolution branchAndBound(KnapsackInstance kp) {
		return null; //TODO
	}

	
	public static KnapsackSolution greedyK(KnapsackInstance kp, int k) {
		return null; //TODO
	}


	public static void main(String[] args) {
		KnapsackInstance kp = readInstance();
		System.out.println(kp);
//		System.out.println(fractional(kp));
//		System.out.println(bruteForce(kp));
//		System.out.println(branchAndBound(kp));
//		System.out.println(dynamicProgramming(kp));
//		System.out.println(greedyK(kp, 5));
	}
}
